Security Issues — mod_wsgi 4.8.0 documentation

# Security Issues

Due to security issues in versions of mod_wsgi up to and including version 3.4, ensure that you are using version 3.5 or later.

Release notes for versions containing security related fixes are:

- Version 3.5

Because many Linux distributions still ship ancient out of date versions, which are not supported, it is highly recommended you avoid using packaged binary versions provided by your Linux distribution. Instead install mod_wsgi from source code, ensuring you keep up to date with the most recent version.